@@ -14,6 +14,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of seasonal sums is written.
 #'@export
@@ -57,6 +59,6 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_seassum.nc")))
-seassum <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  seasx_wrapper(2, var, infile, outfile, nc34, overwrite, verbose)
+seassum <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE, nc = NULL) {
+  seasx_wrapper(2, var, infile, outfile, nc34, overwrite, verbose, nc = nc)
 }
